# Code Radar

Summarizing the code metrics of your project from pytest-cov, pylint and flake8.

**Status:**  early alpha
**Authors:** Carsten König

## Installation

```bash
pip install coderadar
```

## How to use
After you created the required reports with pytest, pylint and flake8, run

```bash
coderadar
```


## License
[MIT](https://choosealicense.com/licenses/mit/)

## Author
**Carsten König**

- [GitLab](https://gitlab.com/ck2go "Carsten König")
- [GitHub](https://github.com/ck2go "Carsten König")
- [LinkedIn](https://www.linkedin.com/in/ck2go/ "Carsten König")
- [Website](https://www.carsten-koenig.de "Carsten König")